@@ -191,7 +191,7 @@ void process_input(int fd)
 	nbytes = read(fd, &event, sizeof(event));
 
 	if (nbytes == 0) {
-		acpid_log(LOG_WARNING, "input layer connection closed\n");
+		acpid_log(LOG_WARNING, "input layer connection closed");
 		exit(EXIT_FAILURE);
 	}
 	
@@ -200,16 +200,16 @@ void process_input(int fd)
 		if (errno == EINTR)
 			return;
 		if (errno == ENODEV) {
-			acpid_log(LOG_WARNING, "input device has been disconnected\n");
+			acpid_log(LOG_WARNING, "input device has been disconnected");
 			delete_connection(fd);
 			return;
 		}
-		acpid_log(LOG_ERR, "input layer read error: %s (%d)\n",
+		acpid_log(LOG_ERR, "input layer read error: %s (%d)",
 			strerror(errno), errno);
 		if (++nerrs >= ACPID_MAX_ERRS) {
 			acpid_log(LOG_ERR,
 				"too many errors reading "
-				"input layer - aborting\n");
+				"input layer - aborting");
 			exit(EXIT_FAILURE);
 		}
 		return;
@@ -220,7 +220,7 @@ void process_input(int fd)
 	
 	if (nbytes != sizeof(event)) {
 		acpid_log(LOG_WARNING, "input layer unexpected length: "
-			"%d   expected: %d\n", nbytes, sizeof(event));
+			"%d   expected: %d", nbytes, sizeof(event));
 		return;
 	}
 
@@ -235,21 +235,21 @@ void process_input(int fd)
 		if (logevents) {
 			acpid_log(LOG_INFO,
 				"lockfile present, not processing "
-				"input layer event \"%s\"\n", str);
+				"input layer event \"%s\"", str);
 		}
 		return;
 	}
 
 	if (logevents)
 		acpid_log(LOG_INFO,
-			"received input layer event \"%s\"\n", str);
+			"received input layer event \"%s\"", str);
 	
 	/* send the event off to the handler */
 	acpid_handle_event(str);
 
 	if (logevents)
 		acpid_log(LOG_INFO,
-			"completed input layer event \"%s\"\n", str);
+			"completed input layer event \"%s\"", str);
 }
 
 #define BITS_PER_LONG (sizeof(long) * 8)
@@ -314,7 +314,7 @@ int open_inputfile(const char *filename)
 		}
 
 		acpid_log(LOG_DEBUG, "input layer %s "
-			"opened successfully\n", filename);
+			"opened successfully", filename);
 
 		/* add a connection to the list */
 		c.fd = fd;
@@ -350,7 +350,7 @@ void open_input(void)
 	}
 
 	if (!success)
-		acpid_log(LOG_ERR, "cannot open input layer\n");
+		acpid_log(LOG_ERR, "cannot open input layer");
 
 	globfree(&globbuf);
 }
